# About clockwork

<img src="https://gitlab.com/octomy/clockwork/-/raw/master/design/clockwork-logo-1024.png" width="20%"/>

Clockwork is a cheduler for tasks tightly linked to [the batch project](https://gitlab.com/octomy/batch)


Clockwork is [available on gitlab](https://gitlab.com/octomy/clockwork).
Clockwork is [available in PyPI](https://pypi.org/project/clockwork/).

```shell
# Install clockwork into your current Python environment
pip install clockwork

```




